package hhenson.core;





/**
* Provides an interface to allow for the development of information filters. This
* interface works at an atomic scale and is not a stream filter.
* The interface provides two basic methods. One to determine if the filter can
* process a specifc type of class and another to determine if the object is a
* match with the filter or not.
* Conceptually the filter should be implemented in a way where only the decisions
* of filters which understand the object type are taken into account. Thus if any
* collection of filters that understand the data type return false then the
* overall filter collection will fail. Rather then failing because a filter could
* not determine a match since it did not understand the object passed to it.
* @author Howard Henson
* @version 1.0
* @generator Enterprise Architect
* @created 19-Aug-2002 11:06:07
*/

public interface Filter {

	/**
	* Returns true if the object passed to the method is a match with the filter requirements.
	* @param    obj    The object to check against the filter criteria.
	*/
	public boolean isMatch(Object obj);
	/**
	* Determines if the filter is defined to work on this specific object type.
	* @param    obj    The object to check
	*/
	public boolean isDefined(Object obj);

}