package hhenson.core;

import java.util.*;

/**
* A collection of filter objects which process a related collection of filters.
* @generator Enterprise Architect
* @created 29-Jul-2002 15:18:24
* @author Howard Henson
* @version 1.0
* @generator Enterprise Architect
* @created 19-Aug-2002 11:06:07
*/

public class FilterCollection implements Filter {

	/**
	* A list of available filters
	*/
	private List filterList = new LinkedList();
	public FilterCollection() {

	}

	/**
	* Returns the 'AND' result of all of the results returned by the list of filters that can process.
	* If no filters can process it returns false. This should be a short circuit operation 
	* in that the first false result should stop the process of checking filters.
	* @param    obj
	*/
	public boolean isMatch(Object obj) {
		Iterator i = filterList.iterator();
		while( i.hasNext() ){
			if( !((Filter)i.next()).isMatch(obj) ){
				return false;
			}
		}
		return true;
	}

	/**
	* 
	* @exception Throwable
	*/
	public void finalize() throws Throwable {

	}

	/**
	* Returns true if any of the filters in the collection of filters is defined
	* to process this type of object. This should be implemented in a short circuit
	* fashion, where the first filter returning true will end the process of looking.
	* @param    obj
	*/
	public boolean isDefined(Object obj) {
		Iterator i = filterList.iterator();
		while( i.hasNext() ){
			if( ((Filter)i.next()).isDefined(obj)){
				return true;
			}	
		}
		return false;
	}

	/**
	* Adds a new filter to the list.
	* @param    filter    The filter to add to the list .
	*/
	public void addFilter(Filter filter) {
		filterList.add(filter);
	}

}