package hhenson.core;

/**
* Cabable of performing matches.
* 
* A match is when two objects can be compared to provide a non one-to-one
* successful comparision. For example an id could contain wild card characters to
* identify what portions of an id should be considered to be equal without
* actually being equal in the traditional sense.
* @author Howard Henson
* @version 1.0
* @updated 26-Aug-2002 09:18:52
*/

public interface Matchable{

	/**
	* Returns true if the comparison object is concidered to be a match for this object.
	* @param    obj    The object to match.
	*/
	public boolean isMatch(Object obj);
	
	/**
	 * Returns true if the object can be expanded.
	 * That is if the object will match with more than one similar object.
	 * For example, if the object is a key and it contains wild card characters
	 * then it is expandable.
	 */
	public boolean isExpandable();
	
	/**
	 * Sets the object to perform loose matching.
	 * Loose matching allows for a lesser set of matching rules to be applied
	 * if applicable. For example when a searck key like dim.* is matched it is
	 * treated as dim.~.
	 */
	public void setLooseMatch(boolean isLooseMatchable);
	
	/**
	 * determines if this object is currently implementing a loose match policy.
	 */
	public boolean isLooseMatch();
}