package hhenson.oodb.entity;

import hhenson.core.*;
import hhenson.oodb.core.*;

/**
 * The number represents the IRS Tax number.
 * A tax number is the representation of an organisation or individual
 * with the Inland Revenue Services and should be unique to the country
 * of the IRS Service.
 * Currently we only support South African IRS numbers. This could be
 * extended by added a country code to the object.
 * @author Howard Henson
 */
public class CommissionerOfInlandRevenueNumber extends OodbIDImpl {

	private String revenueNumber;

	/**
	 * Constructor for CommissionerOfInlandRevenueNumber.
	 */
	public CommissionerOfInlandRevenueNumber() {
		super();
	}

	public CommissionerOfInlandRevenueNumber(String revenueNumber) {
		this.revenueNumber = revenueNumber;
	}

	/**
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object obj) {
		if (obj instanceof CommissionerOfInlandRevenueNumber) {
			return revenueNumber.compareTo(
				((CommissionerOfInlandRevenueNumber) obj).getRevenueNumber());
		}
		return this.getClass().getName().compareTo(obj.getClass().getName());
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		return revenueNumber.equals(obj);
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return revenueNumber;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return revenueNumber.hashCode();
	}

	/**
	 * Returns the revenueNumber.
	 * @return String
	 */
	public String getRevenueNumber() {
		return revenueNumber;
	}

	/**
	 * Sets the revenueNumber.
	 * @param revenueNumber The revenueNumber to set
	 */
	protected void setRevenueNumber(String revenueNumber) {
		this.revenueNumber = revenueNumber;
	}

	/**
	 * @see hhenson.oodb.core.ID#fetchObjectFromDatabase()
	 */
	protected Object fetchObjectFromDatabase()
		throws InvalidIDException, ObjectNotLocatedException {
		return null;
	}

}
