package hhenson.oodb.entity;

import sun.security.krb5.Config;

import goodsjpi.*;
import hhenson.configuration.*;

/**
 * Represents an e-mail address.
 * This object implements simple verification of email address
 * to ensure that the address takes a valid form.
 * @author Howard Henson
 */
public class EmailAddress
	extends Persistent
	implements Comparable, Configurable {

	/**
	 * The user portion of the email address.
	 */
	private String userName;

	/**
	 * The domain portion of the email address.
	 */
	private String domainName;

	/**
	 * Constructor for EmailAddress.
	 */
	public EmailAddress() {
		super();
	}

	/**
	 * Constructor for EmailAddress.
	 */
	public EmailAddress(String address) throws InvalidData {
		super();
		setEmailAddress(address);
	}

	/**
	 * Returns the domainName.
	 * @return String
	 */
	public String getDomainName() {
		return domainName;
	}

	/**
	 * Returns the userName.
	 * @return String
	 */
	public String getUserName() {
		return userName;
	}

	/**
	 * Sets the domainName.
	 * @param domainName The domainName to set
	 */
	public void setDomainName(String domainName) {
		this.domainName = domainName;
	}

	/**
	 * Sets the userName.
	 * @param userName The userName to set
	 */
	public void setUserName(String userName) {
		this.userName = userName;
	}

	/**
	 * sets the email address from a string.
	 */
	public void setEmailAddress(String address) throws InvalidData {
		//split into user and host, ensure host and user do not contain any
		//unpleasant characters
		if (address.indexOf('@') == -1) {
			throw new InvalidData("The email address did not contain a '@' symbol");
		}
		int offset = address.indexOf('@');
		userName = address.substring(0, offset);
		domainName = address.substring(offset + 1, address.length());
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		if (obj instanceof EmailAddress) {
			return this.toString().equals(obj.toString());
		}
		return false;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return userName + "@" + domainName;
	}

	/**
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object obj) {
		if (obj instanceof EmailAddress) {
			return this.toString().compareTo(obj.toString());
		}
		return this.getClass().getName().compareTo(obj.getClass().getName());
	}

	public static final String CFG_USERNAME = "Username";
	public static final String CFG_DOMAIN_NAME = "DomainName";

	/**
	 * @see hhenson.configuration.Configurable#cfgLoad(Configuration)
	 */
	public void cfgLoad(Configuration config) {
		// <Username>Username</Username>
		// <DomainName>Domain</DomainName>
		userName = (String) config.getValue(CFG_USERNAME);
		domainName = (String) config.getValue(CFG_DOMAIN_NAME);
	}

	/**
	 * @see hhenson.configuration.Configurable#cfgStore()
	 */
	public Configuration cfgStore() {
		Configuration conf = Configuration.newInstance();
		conf.setValue(CFG_USERNAME, userName);
		conf.setValue(CFG_DOMAIN_NAME, domainName);
		return conf;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return userName.hashCode() ^ domainName.hashCode();
	}

}
