package hhenson.oodb.entity.company;

import hhenson.core.InvalidIDException;
import hhenson.core.ObjectNotLocatedException;
import hhenson.oodb.core.OodbIDImpl;

/**
 * Represents a branch within a company.
 * 
 * @author Howard Henson
 */
public class BranchID extends OodbIDImpl {
	
	/**
	 * The branch code associated with this branch.
	 */
	private String branchCode;
	
	/**
	 * The company to which the branch belongs to.
	 */
	private CompanyID companyID;

	/**
	 * Constructor for BranchID.
	 */
	public BranchID() {
		super();
	}

	/**
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object o) {
		if (o instanceof BranchID){
			BranchID branchID =(BranchID)o;
			if (companyID.compareTo(branchID.getCompanyID())==0){
				return branchCode.compareTo(branchID.getBranchCode());	
			}
			return companyID.compareTo(branchID.getCompanyID());
		}
		return this.getClass().getName().compareTo(o.getClass().getName());
	}

	/**
	 * Returns the branchCode.
	 * @return String
	 */
	public String getBranchCode() {
		return branchCode;
	}

	/**
	 * Returns the companyID.
	 * @return CompanyID
	 */
	public CompanyID getCompanyID() {
		return companyID;
	}

	/**
	 * Sets the branchCode.
	 * @param branchCode The branchCode to set
	 */
	public void setBranchCode(String branchCode) {
		this.branchCode = branchCode;
	}

	/**
	 * Sets the companyID.
	 * @param companyID The companyID to set
	 */
	public void setCompanyID(CompanyID companyID) {
		this.companyID = companyID;
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object o) {
		if (o instanceof BranchID){
			BranchID branchID =(BranchID)o;
			if (companyID.equals(branchID.getCompanyID())){
				return branchCode.equals(branchID.getBranchCode());	
			}
			return companyID.equals(branchID.getCompanyID());
		}
		return false;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return super.toString();
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return companyID.hashCode()^branchCode.hashCode();
	}

	/**
	 * @see hhenson.oodb.core.ID#fetchObjectFromDatabase()
	 */
	protected Object fetchObjectFromDatabase()
		throws InvalidIDException, ObjectNotLocatedException {
		return null;
	}

}
