package hhenson.oodb.entity.company;

import hhenson.configuration.Configuration;
import hhenson.core.ID;
import hhenson.oodb.entity.Entity;
import hhenson.oodb.roles.employee.Employee;
import java.util.Set;

/**
 * Represents a branch of a company.
 * Branches are not standalone objects but must
 * exist within a company. As such the company
 * associated with the branch is a property of the
 * branch.
 * 
 * A branch typically seperates people into geographical
 * locations.
 * 
 * @author Howard Henson
 */
public class CompanyBranch extends Entity {
	
	/**
	 * The company associated with the branch.
	 */
	private Company company;
	
	/**
	 * The name of the branch.
	 */
	private String name;
	
	/**
	 * The employees associated with this branch.
	 */
	private Set employees;
	
	/**
	 * The id of the cost centre.
	 */
	private ID id;

	/**
	 * Constructor for CompanyBranch.
	 */
	public CompanyBranch() {
		super();
	}

	/**
	 * Constructor for CompanyBranch.
	 * @param id
	 * @param name
	 */
	public CompanyBranch(ID id, String name) {
		super(id, name);
	}

	/**
	 * Returns the company.
	 * @return Company
	 */
	public Company getCompany() {
		return company;
	}

	/**
	 * Sets the company.
	 * @param company The company to set
	 */
	public void setCompany(Company company) {
		this.company = company;
	}

	/**
	 * Returns the employees.
	 * @return Set
	 */
	public Set getEmployees() {
		return employees;
	}

	/**
	 * Returns the id.
	 * @return ID
	 */
	public ID getId() {
		return id;
	}

	/**
	 * Returns the name.
	 * @return String
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the employees.
	 * @param employees The employees to set
	 */
	public void setEmployees(Set employees) {
		this.employees = employees;
	}
	
	/**
	 * Addes an employee to the Set.
	 */
	public void addEmployee(Employee employee) {
		employees.add(employee);
	}

	/**
	 * Sets the id.
	 * @param id The id to set
	 */
	public void setId(ID id) {
		this.id = id;
	}

	/**
	 * Sets the name.
	 * @param name The name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	public static final String CFG_COMPANY="Company";
	public static final String CFG_COMPANY_BRANCH_NAME="Name";
	public static final String CFG_EMPLOYEES="Employees";
	public static final String CFG_COST_CENTRE_ID="Id";
	/**
	 * @see hhenson.configuration.Configurable#cfgLoad(Configuration)
	 */
	public void cfgLoad(Configuration config) {
		super.cfgLoad(config);
		company=(Company)config.getValue(CFG_COMPANY);
		name=(String)config.getValue(CFG_COMPANY_BRANCH_NAME);
		employees=(Set) config.getValue(CFG_EMPLOYEES);
		id=(CostCentreID)config.getValue(CFG_COST_CENTRE_ID);
	}

	/**
	 * @see hhenson.configuration.Configurable#cfgStore()
	 */
	public Configuration cfgStore() {
		Configuration config= super.cfgStore();
		config.setValue(CFG_COMPANY, company);
		config.setValue(CFG_COMPANY_BRANCH_NAME, name);
		config.setValue(CFG_EMPLOYEES, employees);
		config.setValue(CFG_COST_CENTRE_ID, id); 
		return config;
	}

}
