package hhenson.oodb.entity.company;

import hhenson.core.ID;
import java.util.Set;

/**
 * A pay point is an entity that is repsonsible for making payments
 * for company. The pay point aggregates cost centres and make payments
 * to and for that cost centre.
 * 
 * The paypoint should have their own unique code within the
 * company. A simple Paypoint id is provided.
 * 
 * @author Howard Henson
 */
public class CompanyPayPoint {

	/**
	 * The company associated with the paycentre.
	 */
	private Company company;

	/**
	 * The name of the pay centre.
	 */
	private String name;

	/**
	 * The id of the pay centre.
	 */
	private ID id;

	/**
	 * The cost centres (CostCentre) to associate with this
	 * paypoint.
	 */
	private Set costCentres;

	/**
	 * Constructor for CompanyPayPoint.
	 */
	public CompanyPayPoint() {
		super();
	}

	/**
	 * Returns the company.
	 * @return Company
	 */
	public Company getCompany() {
		return company;
	}

	/**
	 * Returns the costCentres.
	 * @return Set
	 */
	public Set getCostCentres() {
		return costCentres;
	}

	/**
	 * Returns the id.
	 * @return ID
	 */
	public ID getId() {
		return id;
	}

	/**
	 * Returns the name.
	 * @return String
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the company.
	 * @param company The company to set
	 */
	public void setCompany(Company company) {
		this.company = company;
	}

	/**
	 * Sets the costCentres.
	 * @param costCentres The costCentres to set
	 */
	public void setCostCentres(Set costCentres) {
		this.costCentres = costCentres;
	}

	/**
	 * Sets the id.
	 * @param id The id to set
	 */
	public void setId(ID id) {
		this.id = id;
	}

	/**
	 * Sets the name.
	 * @param name The name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		if (obj instanceof CompanyPayPoint) {
			return id.equals(((CompanyPayPoint) obj).getId());
		}
		return false;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return id.hashCode();
	}

}
