package hhenson.oodb.entity.company;

import hhenson.core.ID;
import hhenson.oodb.roles.employee.Employee;
import java.util.Set;

/**
 * A cost centre is the point where costs are agregated and reported.
 * This is often synonimous with department.
 * @author Howard Henson
 */
public class CostCentre {
	
	/**
	 * The company associated with the cost centre.
	 */
	private Company company;
	
	/**
	 * The name of the cost centre.
	 */
	private String name;
	
	/**
	 * The id of the cost centre.
	 */
	private ID id;
	
	/**
	 * The employees associated with this cost centre.
	 */
	private Set employees;
	
	/**
	 * Constructor for CostCentre.
	 */
	public CostCentre() {
		super();
	}

	/**
	 * Returns the company.
	 * @return Company
	 */
	public Company getCompany() {
		return company;
	}

	/**
	 * Returns the employees.
	 * @return Set
	 */
	public Set getEmployees() {
		return employees;
	}

	/**
	 * Returns the id.
	 * @return ID
	 */
	public ID getId() {
		return id;
	}

	/**
	 * Returns the name.
	 * @return String
	 */
	public String getName() {
		return name;
	}

	/**
	 * Sets the company.
	 * @param company The company to set
	 */
	public void setCompany(Company company) {
		this.company = company;
	}

	/**
	 * Sets the employees.
	 * @param employees The employees to set
	 */
	public void setEmployees(Set employees) {
		this.employees = employees;
	}
	
	/**
	 * Sets the employees.
	 * @param employees The employees to set
	 */
	public void addEmployee(Employee employee) {
		employees.add(employee);
	}


	/**
	 * Sets the id.
	 * @param id The id to set
	 */
	public void setId(ID id) {
		this.id = id;
	}

	/**
	 * Sets the name.
	 * @param name The name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		if (obj instanceof CostCentre){
			return id.equals(((CostCentre)obj).getId());	
		}
		return false;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return id.hashCode();
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return id.toString();
	}

}
