package hhenson.oodb.entity.company;

import hhenson.core.InvalidIDException;
import hhenson.core.ObjectNotLocatedException;
import hhenson.oodb.core.OodbIDImpl;

/**
 * The ID of the cost centre.
 * @author Howard Henson
 */
public class CostCentreID extends OodbIDImpl {
	
	/**
	 * The cost centre code. This is assigned and
	 * maintained by the company themselves and typically
	 * ties up to ledger codes on the accounting system.
	 */
	private String costCentreCode;
	
	/**
	 * The id of the company associated with the cost cetre.
	 */
	private CompanyID companyID;

	/**
	 * Constructor for CostCentreID.
	 */
	public CostCentreID() {
		super();
	}

	/**
	 * Need to compare that the companyID and the costCentreCode is the same
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object o) {
		if (o instanceof CostCentreID){
			CostCentreID costCentreID=(CostCentreID)o;
			if (companyID.compareTo(costCentreID.getCompanyID())==0){
				return costCentreCode.compareTo(costCentreID.getCostCentreCode());
			}
			return companyID.compareTo(costCentreID.getCompanyID());	
		}
		return -1;
	}

	/**
	 * Returns the companyID.
	 * @return CompanyID
	 */
	public CompanyID getCompanyID() {
		return companyID;
	}

	/**
	 * Returns the costCentreCode.
	 * @return String
	 */
	public String getCostCentreCode() {
		return costCentreCode;
	}

	/**
	 * Sets the companyID.
	 * @param companyID The companyID to set
	 */
	public void setCompanyID(CompanyID companyID) {
		this.companyID = companyID;
	}

	/**
	 * Sets the costCentreCode.
	 * @param costCentreCode The costCentreCode to set
	 */
	public void setCostCentreCode(String costCentreCode) {
		this.costCentreCode = costCentreCode;
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object o) {
		if (o instanceof CostCentreID){
			CostCentreID costCentreID=(CostCentreID)o;
			if (companyID.equals(costCentreID.getCompanyID())){
				return costCentreCode.equals(costCentreID.getCostCentreCode());
			}	
		}
		return false; 
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return super.toString();
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return companyID.hashCode()^costCentreCode.hashCode();
	}

	/**
	 * @see hhenson.oodb.core.ID#fetchObjectFromDatabase()
	 */
	protected Object fetchObjectFromDatabase()
		throws InvalidIDException, ObjectNotLocatedException {
		return null;
	}

}
