package hhenson.oodb.roles.employee;

import hhenson.core.InvalidIDException;
import hhenson.core.ObjectNotLocatedException;
import hhenson.oodb.core.OodbIDImpl;
import hhenson.oodb.entity.company.CompanyID;

/**
 * The id that represents the employee within a company.
 * @author Howard Henson
 */
public class EmployeeID extends OodbIDImpl {

	/**
	 * The code or number associated with an
	 * employee of a company that is generated and maintained
	 * by the company.
	 */
	private String employeeCode;

	/**
	 * The company id.
	 */
	private CompanyID companyID;

	/**
	 * Constructor for EmployeeID.
	 */
	public EmployeeID() {
		super();
	}

	/**
	 * The ids are equal if the companyID and the employee code are the same
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object o) {
		if (o instanceof EmployeeID) {
			EmployeeID employeeID = (EmployeeID) o;
			if (companyID.compareTo(employeeID.getCompanyID()) == 0) {
				return employeeCode.compareTo(employeeID.getEmployeeCode());
			}
			return companyID.compareTo(employeeID.getCompanyID());
		}
		return this.getClass().getName().compareTo(o.getClass().getName());
	}

	/**
	* @see java.lang.Object#hashCode()
	*/
	public int hashCode() {
		return companyID.hashCode()^ employeeCode.hashCode();
	}
	/**
			 * @see java.lang.Object#equals(Object)
			 */
	public boolean equals(Object o) {
		if (o instanceof EmployeeID) {
			if (companyID.equals(((EmployeeID) o).getCompanyID())) {
				return employeeCode.equals(((EmployeeID) o).getEmployeeCode());
			}
		}
		return false;
	}

	/**
			 * @see java.lang.Object#toString()
			 */
	public String toString() {
		return super.toString();
	} /**
				 * Returns the companyID.
				 * @return CompanyID
				 */
	public CompanyID getCompanyID() {
		return companyID;
	} /**
				 * Returns the employeeCode.
				 * @return String
				 */
	public String getEmployeeCode() {
		return employeeCode;
	} /**
				 * Sets the companyID.
				 * @param companyID The companyID to set
				 */
	public void setCompanyID(CompanyID companyID) {
		this.companyID = companyID;
	} /**
				 * Sets the employeeCode.
				 * @param employeeCode The employeeCode to set
				 */
	public void setEmployeeCode(String employeeCode) {
		this.employeeCode = employeeCode;
	}

	/**
	 * @see hhenson.oodb.core.ID#fetchObjectFromDatabase()
	 */
	protected Object fetchObjectFromDatabase()
		throws InvalidIDException, ObjectNotLocatedException {
		return null;
	}

}
