package hhenson.oodb.roles.employee;

import goodsjpi.Persistent;
import hhenson.configuration.Configurable;
import hhenson.configuration.Configuration;
import hhenson.oodb.util.Money;

/**
 * Salaries are the moneys paid to employed persons for services rendered.
 * 
 * @author Howard Henson
 */
public class SalaryInformation extends Persistent implements Comparable, Configurable {

	public static final int WEEKLY = 1;
	public static final int FORTNIGHTLY = 2;
	public static final int MONTHLY = 3;
	/**
	 * This is when a salary is derived from sources
	 * that are not consistent in their payment dates.
	 * For example a commision only salesman will get
	 * paid when they make sales only.
	 */
	public static final int NON_PERIODIC = 4;
	
	/**
	 * The frequency that the salary is generated with.
	 * For example a monthly salary.
	 */
	private int frequecy;
	
	/**
	 * The total salary earned by the individual. This is the
	 * amount earned for the frequency set.
	 */
	private Money grossSalary;
	
	/**
	 * The amount of the salary that is deemed pensionable.
	 * This is the amount for the freqency set.
	 */
	private Money pensionableSalary;
	
	/**
	 * The risk portion of the salary is determined as follows:
	 * grossSalary - pensionableSalary
	 */
	public Money getRiskSalary(){
		return null;
	}
	
	/**
	 * Constructor for SalaryInformation.
	 */
	public SalaryInformation() {
		super();
	}

	/**
	 * @see java.lang.Comparable#compareTo(Object)
	 */
	public int compareTo(Object o) {
		return 0;
	}

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		return super.equals(obj);
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return super.toString();
	}

	public static final String CFG_FREQUENCY="Frequency";
	public static final String CFG_GROSS_SALARY="GrossSalary";
	public static final String CFG_PENSIONABLE_SALARY="PensionableSalary";
	/**
	 * @see hhenson.configuration.Configurable#cfgLoad(Configuration)
	 */
	public void cfgLoad(Configuration config) {
		String temp=(String)config.getValue(CFG_FREQUENCY); 
		if (temp!=null){
			frequecy=Integer.parseInt(temp);
		}
		grossSalary=(Money)config.getValue(CFG_GROSS_SALARY);
		pensionableSalary=(Money)config.getValue(CFG_PENSIONABLE_SALARY);
	}

	/**
	 * @see hhenson.configuration.Configurable#cfgStore()
	 */
	public Configuration cfgStore() {
		Configuration config=Configuration.newInstance();
		config.setValue(CFG_FREQUENCY, Integer.toString(frequecy)); 
		config.setValue(CFG_GROSS_SALARY, grossSalary);
		config.setValue(CFG_PENSIONABLE_SALARY, pensionableSalary);
		return config;
	}

	/**
	 * Returns the frequecy.
	 * @return int
	 */
	public int getFrequecy() {
		return frequecy;
	}

	/**
	 * Returns the grossSalary.
	 * @return Money
	 */
	public Money getGrossSalary() {
		return grossSalary;
	}

	/**
	 * Returns the pensionableSalary.
	 * @return Money
	 */
	public Money getPensionableSalary() {
		return pensionableSalary;
	}

	/**
	 * Sets the frequecy.
	 * @param frequecy The frequecy to set
	 */
	public void setFrequecy(int frequecy) {
		this.frequecy = frequecy;
	}

	/**
	 * Sets the grossSalary.
	 * @param grossSalary The grossSalary to set
	 */
	public void setGrossSalary(Money grossSalary) {
		this.grossSalary = grossSalary;
	}

	/**
	 * Sets the pensionableSalary.
	 * @param pensionableSalary The pensionableSalary to set
	 */
	public void setPensionableSalary(Money pensionableSalary) {
		this.pensionableSalary = pensionableSalary;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return super.hashCode();
	}

}
