package hhenson.oodb.roles.users;

import goodsjpi.Persistent;

import hhenson.roles.user.AuthenticationToken;

/**
 * Ultimately this should represent a generic authentication token.
 * At this point in time the only authentication token available is
 * a password. Thus this currently represents a password.
 * @author Howard Henson
 */
public class OodbAuthenticationTokenImpl extends Persistent implements AuthenticationToken {
	
	private String password;

	/**
	 * Constructor for AuthenticationToken.
	 */
	public OodbAuthenticationTokenImpl() {
		super();
	}

	/**
	 * Constructs a new authentication token with the string based password.
	 */
	public OodbAuthenticationTokenImpl(String token){
		setPassword(token);
	}
	
	/**
	 * Takes a string a stores it as a password.
	 * Currently this is stored in a string but needs to be
	 * encrypted at this point to protect it from prying eyes.
	 */
	protected void setPassword( String password){
		this.password = password;
	}
	

	/**
	 * @see java.lang.Object#equals(Object)
	 */
	public boolean equals(Object obj) {
		if( obj instanceof OodbAuthenticationTokenImpl ){
			return password.equals(((OodbAuthenticationTokenImpl)obj).password);
		}
		return false;
	}

	/**
	 * @see java.lang.Object#hashCode()
	 */
	public int hashCode() {
		return password.hashCode();
	}
	
	public String toString(){
		return password;
	}

}
