package hhenson.oodb.rules;

import hhenson.utils.BitmapTools;

/**
 * Contains the results generated by executing a rule.
 * 
 * @author Howard Henson
 */
public class RuleResults {

	/**
	 * Secifies that there is a boolean component to this result.
	 */
	public static final int BOOLEAN_RESULT = 1;

	/**
	 * Specifies that there is a double component to this result.
	 */
	public static final int DOUBLE_RESULT = 2;

	/**
	 * determines the nature of the result.
	 */
	private int resultType = 0;

	/**
	 * The boolean value if set.
	 */
	private boolean booleanValue;

	/**
	 * The double value if set.
	 */
	private double doubleValue;

	/**
	 * Constructor for RuleResults.
	 */
	public RuleResults() {
		super();
	}

	/**
	 * Returns the doubleValue.
	 * @return double
	 */
	public double getDoubleValue() throws InvalidResultTypeException {
		if (BitmapTools.isMaskSet(resultType, DOUBLE_RESULT)) {
			return doubleValue;
		} else {
			throw new InvalidResultTypeException("No double value set");
		}
	} 
	
	/**
	 * Returns the resultType.
	 * @return int
	 */
	public int getResultType() {
		return resultType;
	}
	
	/**
	 * Sets the doubleValue.
	 * @param doubleValue The doubleValue to set
	 */
	public void setDoubleValue(double doubleValue) {
		resultType |= DOUBLE_RESULT;
		this.doubleValue = doubleValue;
	}
	
	 /**
	  * Sets the resultType.
	  * @param resultType The resultType to set
	  */
	protected void setResultType(int resultType) {
		this.resultType = resultType;
	}

	/**
	 * Returns the booleanValue.
	 * @return boolean
	 */
	public boolean isBooleanValue() throws InvalidResultTypeException {
		if (BitmapTools.isMaskSet(resultType, BOOLEAN_RESULT)) {
			return booleanValue;
		} else {
			throw new InvalidResultTypeException("No boolean value set");
		}
	}

	/**
	 * Sets the booleanValue.
	 * @param booleanValue The booleanValue to set
	 */
	public void setBooleanValue(boolean booleanValue) {
		resultType |= BOOLEAN_RESULT;
		this.booleanValue = booleanValue;
	}

}
