package hhenson.oodb.services.ocache;

import goodslib.PersistentHashMap;
import hhenson.services.ocache.ObjectCacheContext;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.InvalidNameException;
import javax.naming.Name;
import javax.naming.NameNotFoundException;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;

import org.apache.avalon.excalibur.naming.AbstractLocalContext;
import org.apache.avalon.excalibur.naming.Namespace;
import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.configuration.Configuration;
import org.apache.avalon.framework.configuration.ConfigurationException;

/**
 * Implements the ObjectCacheContext interface in order to provide a standardised interface
 * to the object repositorty. By binding objects here they will be persisted in the object
 * database associated with this context.
 * 
 * The object database should be configured via the configurable interface.
 * 
 * @author Howard Henson
 */
public class OodbObjectCacheContextImpl
	extends AbstractLocalContext
	implements ObjectCacheContext {
	private PersistentHashMap m_bindings;

	protected OodbObjectCacheContextImpl(
		final Namespace namespace,
		final Hashtable environment,
		final Context parent,
		final PersistentHashMap bindings) {
		super(namespace, environment, parent);
		m_bindings = bindings;
	}

	public OodbObjectCacheContextImpl(
		final Namespace namespace,
		final Hashtable environment,
		final Context parent) {
		this(namespace, environment, parent, new PersistentHashMap(40));
	}

	protected Context newContext() throws NamingException {
		return new OodbObjectCacheContextImpl(
			getNamespace(),
			getRawEnvironment(),
			getParent());
	}

	protected Context cloneContext() throws NamingException {
		return new OodbObjectCacheContextImpl(
			getNamespace(),
			getRawEnvironment(),
			getParent(),
			m_bindings);
	}

	protected void doLocalBind(final Name name, final Object object)
		throws NamingException {
		m_bindings.put(name.get(0), object);
	}

	protected NamingEnumeration doLocalList() throws NamingException {
		return new OodbNamingEnumeration(
			this,
			getNamespace(),
			m_bindings,
			false);
	}

	protected NamingEnumeration doLocalListBindings() throws NamingException {
		return new OodbNamingEnumeration(
			this,
			getNamespace(),
			m_bindings,
			true);
	}

	/**
	 * Actually lookup raw entry in local context.
	 * When overidding this it is not neccesary to resolve references etc.
	 *
	 * @param name the name in local context (size() == 1)
	 * @return the bound object
	 * @exception NamingException if an error occurs
	 */
	protected Object doLocalLookup(final Name name) throws NamingException {
		final Object object = m_bindings.get(name.get(0));
		if (null == object)
			throw new NameNotFoundException(name.get(0));
		return object;
	}

	/**
	 * Actually unbind raw entry in local context.
	 *
	 * @param name the name in local context (size() == 1)
	 * @exception NamingException if an error occurs
	 */
	protected void doLocalUnbind(final Name name) throws NamingException {
		m_bindings.remove(name.get(0));
	}
	
	/**
	 * @see hhenson.services.ocache.ObjectCacheContext#isBound(Name)
	 */
	public boolean isBound(Name name) throws NamingException {
		if (isSelf(name)) {
			return true;
		}
		if (1 == name.size()) {
			return m_bindings.containsKey(name.get(0));
		} else {
			final Context context = lookupSubContext(getPathName(name));
			return ((OodbObjectCacheContextImpl) context).isBound(getLeafName(name));
		}
	}

	/**
	 * @see hhenson.services.ocache.ObjectCacheContext#isBound(String)
	 */
	public boolean isBound(String name) throws NamingException {
		return isBound(getNameParser().parse(name));
	}

}
