package hhenson.oodb.util;

import hhenson.core.*;
import hhenson.oodb.entity.CountryCodes;
import hhenson.oodb.util.*;

/**
 * This exception is thrown when an operation is performed on a
 * Money object where the currencies are not the same.
 * 
 * @author Howard Henson
 */
public class CurrencyMismatchException extends FieldMismatchException {

	/**
	 * Constructor for CurrencyMismatchException.
	 */
	public CurrencyMismatchException() {
		super();
	}

	/**
	 * Constructor for CurrencyMismatchException.
	 * @param message
	 */
	public CurrencyMismatchException(String message) {
		super(message);
	}

	/**
	 * Constructor for CurrencyMismatchException.
	 * @param message
	 * @param cause
	 */
	public CurrencyMismatchException(String message, Throwable cause) {
		super(message, cause);
	}

	/**
	 * Constructor for CurrencyMismatchException.
	 * @param cause
	 */
	public CurrencyMismatchException(Throwable cause) {
		super(cause);
	}

	/**
	 * Constructs a new mismatch object from the currencies that caused
	 * the mismatch.
	 */
	public CurrencyMismatchException(Money m1, Money m2) {
		super(
			"Currency mismatch "
				+ CountryCodes
					.COUNTRY_NAMES[m1
					.getCurrency()][CountryCodes
					.COUNTRY_CURRENCY_CODE]
				+ ":"
				+ CountryCodes
					.COUNTRY_NAMES[m2
					.getCurrency()][CountryCodes
					.COUNTRY_CURRENCY_CODE]);
	}
}
