package hhenson.roles;

import hhenson.configuration.Configurable;
import hhenson.utils.DateRange;

/**
 * A role contained within another role.
 * This could be used to define a concept such as roles within an employee role.
 * This type of role is not identifiable, in that it has no existance outside of a role,
 * thus it is a property of a role and can be identified as uniquely by its name within
 * the roles collection of contained roles.
 * @author Howard Henson
 */
public interface ContainedRole extends Comparable, Configurable {
	/**
	 * Returns the associatedRole.
	 * @return Role
	 */
	public Role getAssociatedRole();
	
	/**
	 * Sets the associatedRole.
	 * @param associatedRole The associatedRole to set
	 */
	public void setAssociatedRole(Role associatedRole);
	
	/**
	 * Returns the validDateRange.
	 * @return DateRange
	 */
	public DateRange getValidDateRange();
	
	/**
	 * Sets the validDateRange.
	 * @param validDateRange The validDateRange to set
	 */
	public void setValidDateRange(DateRange validDateRange);
	
	/**
	 * Returns the name.
	 * @return String
	 */
	public String getName();
	
	/**
	 * Sets the name.
	 * @param name The name to set
	 */
	public void setName(String name);
}
