package hhenson.roles;

import hhenson.configuration.Configurable;
import hhenson.core.Identifiable;
import hhenson.oodb.entity.Person;
import hhenson.utils.DateRange;


/**
 * A role represents the different things that a Person can be.
 * <p>
 * A role is always associated with an entity or in this case a person.
 * A role is a set of attributes and meanings that can be applied
 * to a person but will change over time.
 * </p>
 * <p>
 * Example, a person plays the role of child and later could plays the role
 * of parent. Also a person can be a student and later an employed person
 * or both.
 * </p>
 *
 * This provides a template of what a role should perform in order to allow
 * multiple different types of role implementations.
 * 
 * @author Howard Henson
 */
public interface Role extends Comparable, Configurable, Identifiable {
	/**
	 * Returns the person.
	 * @return Person
	 */
	public Person getPerson();
	
	/**
	 * Sets the person.
	 * @param person The person to set
	 */
	public void setPerson(Person person);
	
	/**
	 * Returns the validDateRange.
	 * @return DateRange
	 */
	public DateRange getValidDateRange();
	
	/**
	 * Sets the validDateRange.
	 * @param validDateRange The validDateRange to set
	 */
	public void setValidDateRange(DateRange validDateRange);
}
