package hhenson.roles.user;

import hhenson.roles.Role;

/**
 * A user is a role associated with a person that is used to 
 * identify an ability to make use of the applications
 * associated with the object in the database.
 * 
 * A user has: <br>
 * <ul><li><b>Profiles</b> - A profile contains information regarding what the
 * user has available to them in terms of services and the configurations
 * associated with the service.</li>
 * <li><b>Authentication Information</b> - Information that is utilised
 * in order to be able to authenticate the individual. An example
 * could be a password token.</li>
 * <li><b>UserID</b> - The user id to associated with this user role.</li>
 * </ul>
 * 
 * @author Howard Henson
 */
public interface User extends Role {

	/**
	 * Determines if the user account is locked.
	 */
	public boolean isLocked();

	/**
	 * Attempts to authenticate the user using the given token. If the
	 * token does not correspond with the correct token the failed login
	 * count is incremented. After 3 failed attempts the User will stop
	 * trying to authenticate and will throw a UserLockedException irrespective of the
	 * value passed. The lock will reset itself after a timeout
	 * determined by the number of failed logon attempts. Each time the system locks
	 * itself the timeout is incremented by a power of two. After a successful authentication
	 * all the paramters are reset to their default values.
	 */
	public boolean authenticate(AuthenticationToken givenToken) throws UserLockedException;
	
	/**
	 * Sets the token.This should only be done by an authorised process.
	 * Need to put something along those lines in place!
	 * @param token The token to set
	 */
	public void setToken(AuthenticationToken token);
}
