package hhenson.roles.user;

import hhenson.core.*;
import hhenson.core.ID;
import hhenson.core.InvalidIDException;

/**
 * The unique representation of a user within the system.
 * 
 * @author Howard Henson
 */
public interface UserID extends ID {

	/**
	 * Returns the user id as a string
	 */
	public String getUserName();
	
	/**
	 * Returns true if this id represents an authenticated
	 * session with the user. The token is time sensitive
	 * and will expire after a pre-defined time out.
	 * If access to this userID is lost then the authentication
	 * is lost. For this to work the authentication must have
	 * been performed via this userID.
	 */
	public boolean isAuthenticated();
	
	/**
	 * Authenticates the user associated with this user id.
	 * If this returns false the user could not be authenticated.
	 * The session id is a string unique to the current session instance associated
	 * with this user.
	 */
	public boolean authenticateUser( AuthenticationToken token, String sessionID ) throws InvalidIDException, ObjectNotLocatedException, UserLockedException;
	
	/**
	 * Returns the session id associated with this user id.
	 */
	public String getSessionID();

}
