package hhenson.services.ocache;

import javax.naming.*;

/**
 * Provides access to an object cache which can be backed by
 * an OODB, JDO container, etc.
 * 
 * Additional methods are provided over and above the standard context methods
 * to perform tasks such as determining if a context is already bound, i.e.
 * exists as a context and may have an object or subcontext associated with the context.
 * @author Howard Henson
 */
public interface ObjectCacheContext extends Context {
	public String ROLE = ObjectCacheContext.class.getName();
	
	/**
	 * Identifies if the name already exists as a context or
	 * has an object associated with it.
	 * @param name the name of the context
	 */
	public boolean isBound(Name name) throws NamingException;
	/**
	 * Identifies if the name already exists as a context or
	 * has an object associated with it.
	 * @param name the string name of the object
	 */
	public boolean isBound(String name) throws NamingException;
}
