package hhenson.services.testpack;

import goodslib.PersistentString;
import hhenson.services.ocache.ObjectCacheContext;
import hhenson.services.ocache.ObjectInitialContextFactory;
import javax.security.auth.DestroyFailedException;
import javax.security.auth.Destroyable;

import org.apache.avalon.framework.activity.Disposable;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

/**
 * Tests the Object cache service.
 * 
 * @phoenix:block
 * @phoenix:service name="hhenson.services.testpack.ContextTester"
 * @author Howard Henson
 */
public class ContextTesterImpl extends AbstractLogEnabled implements ContextTester, Serviceable, Disposable {

	ServiceManager m_serviceManager;
	
	/**
	 * Constructor for ContextTesterImpl.
	 */
	public ContextTesterImpl() {
		super();
	}

	/**
	 * @see hhenson.services.testpack.TestPack#test()
	 */
	public boolean test() {
		//try and get an initial context. Then bind a persistable object
		ObjectInitialContextFactory ctxFactory;
		try{
			ctxFactory = (ObjectInitialContextFactory) m_serviceManager.lookup(ObjectInitialContextFactory.ROLE);
		} catch( Exception e ){
			getLogger().error("Could not get access to the ObjectInitialContextFactory", e);
			return false;
		}
		ObjectCacheContext ctx;
		try{
			ctx = (ObjectCacheContext) ctxFactory.getInitialContext(null);
			getLogger().info("Got initial context");
		} catch( Exception e ) {
			getLogger().error("Could not get Initial Context", e);
			m_serviceManager.release(ctxFactory);
			return false;
		}
		try{
			ctx.bind("Test", "This is a test");
			getLogger().info("Bound Test message");
		} catch( Exception e ){
			getLogger().error("Failed to bind test object", e);
			return false;
		}
		Object obj;
		try{
			obj = ctx.lookup("Test");
			getLogger().info("Looked up test binding point");
		} catch( Exception e ){
			getLogger().error("Failed to lookup binding point", e);
			return false;
		}
		boolean rVal;
		if( obj == null ){
			getLogger().error("The returned object was null");
			rVal = false;
		} else {
			getLogger().info("Object class: " + obj.getClass().getName());
			getLogger().info("Object value: " + obj.toString() );
			rVal = obj.toString().equals("This is a test");
		}
		if( rVal ){
			getLogger().info("String retrieval was successful");
		} else {
			getLogger().info("The string retrieval failed, string does not match entered string");
		}
		try{
			ctx.unbind("Test");
			getLogger().info("Successful unbind of Test context");
		} catch( Exception e ){
			getLogger().error("Failed to unbind test context", e);
			return false;
		}
		m_serviceManager.release(ctxFactory);
		getLogger().info("Released factory");
		return rVal;
	}

	/**
	 * @phoenix:dependency name="hhenson.services.ocache.ObjectInitialContextFactory"
	 * @see org.apache.avalon.framework.service.Serviceable#service(ServiceManager)
	 */
	public void service(ServiceManager manager) throws ServiceException {
		m_serviceManager = manager;
	}

	/**
	 * @see org.apache.avalon.framework.activity.Disposable#dispose()
	 */
	public void dispose() {
		m_serviceManager = null;
	}

}
