package hhenson.services.testpack;

import hhenson.roles.user.User;
import hhenson.roles.user.UserID;
import hhenson.services.ocache.ObjectCacheContext;
import hhenson.services.ocache.ObjectInitialContextFactory;
import hhenson.services.user.UserManagementService;

import javax.naming.spi.InitialContextFactory;

import org.apache.avalon.framework.activity.Disposable;
import org.apache.avalon.framework.logger.AbstractLogEnabled;
import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

/**
 * Tests the oodb version of the user management classes.
 * 
 * @phoenix:block
 * @phoenix:service name="hhenson.services.testpack.UserTester"
 * @author Howard Henson
 * @version 1.0
 */
public class UserTesterImpl
	extends AbstractLogEnabled
	implements UserTester, Serviceable, Disposable {

	private ServiceManager m_service;

	/**
	 * Constructor for UserTesterImpl.
	 */
	public UserTesterImpl() {
		super();
	}

	/**
	 * @see hhenson.services.testpack.TestPack#test()
	 */
	public boolean test() {
		boolean rVal = true;
		UserManagementService userManager = null;
		try {
			userManager =
				(UserManagementService) m_service.lookup(
					UserManagementService.ROLE);
			getLogger().info("Got user manager");
			if (userManager.hasUser("howard")) {
				getLogger().info("User howard exists");
				userManager.deleteUser("howard");
				getLogger().info("Deleted user howard");
				getLogger().info(
					"Assuming that this is the second run, so we are going to quit now");
				return true;
			}
			User user = userManager.createNewUser("howard", "howardh");
			getLogger().info("Constructed new user");
			UserID userID = userManager.logOn("howard", "howardh", "session1");
			if (userID == null) {
				getLogger().error(
					"Failed to log on successfully, userID = null");
				rVal = false;
			} else {
				getLogger().info("Loged on successfully");
				if (!user.getId().equals(userID)) {
					getLogger().error(
						"Userid's don't match ["
							+ user.getId().toString()
							+ ", "
							+ userID.toString()
							+ " ]");
					rVal = false;
				} else {
					getLogger().info("UserId's matched");
				}
				userManager.logOff(userID);
				getLogger().info(
					"logged off user, testing complete, run a second time to see if the user was successfully persisted");
			}
		} catch (Exception e) {
			getLogger().error("Failed to process the test", e);
			rVal = false;
		} finally {
			if (userManager != null) {
				m_service.release(userManager);
			}
		}
		return rVal;
	}

	/**
	 * @phoenix:dependency name="hhenson.services.user.UserManagementService"
	 * @see org.apache.avalon.framework.service.Serviceable#service(ServiceManager)
	 */
	public void service(ServiceManager manager) throws ServiceException {
		m_service = manager;
	}

	/**
	 * @see org.apache.avalon.framework.activity.Disposable#dispose()
	 */
	public void dispose() {
		m_service = null;
	}

}
