package hhenson.utils;

import java.util.BitSet;

/**
 * Tools to manipulate a simple integer bitmap.
 * Although the java.util.BitSet provides a convenient set
 * of bitmap manipulation routines, this is a much
 * simplified set of methods to provide a simple
 * flag set based on an integer value.
 * @author Howard Henson
 */
public class BitmapTools {

	/**
	 * Checks to see if the mask is set on the bitmap.
	 * This is useful to chek bits set on an int by
	 * passing a mask which contains the mask that
	 * represents the bit to check.
	 * @param bitMap the holder of the bits.
	 * @param bitMask the mask to check.
	 */
	public static boolean isMaskSet(int bitMap, int bitMask){
		return (bitMask == (bitMap & bitMask));
	}

	/**
	 * Sets the mask on the bitmap.
	 * This ensures that all the bits set in the mask
	 * are set to on in the bitMap.
	 * @param bitMap the holder of the bits.
	 * @param bitMask the mask to set
	 */
	public static int setMask(int bitMap, int bitMask){
		return (bitMap | bitMask);
	}
	
	/**
	 * Sets the bits defined in the mask to zero.
	 * @param bitMap the holder of the bits.
	 * @param bitMask the mask to unset.
	 */
	public static int unsetMask(int bitMap, int bitMask){
		return bitMap - (bitMap & bitMask);
	}

}
