package hhenson.utils;

import java.util.Date;

import hhenson.configuration.Configurable;


/**
 * A date range contains properties for from date and to date.
 * The object also provides some useful methods such as hasEndDate, etc.
 * 
 * @author Howard Henson
 */
public interface DateRange 
	extends Comparable, Configurable {
	
	/**
	 * Determines if a range is contained within this range.
	 * Containment is determined if fromDate&lt;=dateRange.fromDate
	 * and toDate&gt;=dateRange.toDate.
	 */
	public boolean containsRange(DateRange dateRange);

	
	/**
	 * Returns the fromDate.
	 * @return Date
	 */
	public Date getFromDate();
	
	/**
	 * Returns the toDate.
	 * @return Date
	 */
	public Date getToDate();

	/**
	 * Sets the fromDate.
	 * @param fromDate The fromDate to set
	 */
	public void setFromDate(Date fromDate);

	/**
	 * Sets the toDate.
	 * @param toDate The toDate to set
	 */
	public void setToDate(Date toDate);
	
}
